@@ -1,7 +1,7 @@
 package Finance::Bank::ID::BCA;
 
-our $DATE = '2017-07-01'; # DATE
-our $VERSION = '0.46'; # VERSION
+our $DATE = '2017-07-20'; # DATE
+our $VERSION = '0.47'; # VERSION
 
 use 5.010001;
 use Moo;
@@ -323,17 +323,17 @@ sub _ps_get_transactions {
     my @e;
     # text version
     while ($page =~ m!^
-(\d\d/\d\d|\s?PEND|\s?NEXT)
-  (?:\s*\t\s*|\n)
-((?:[^\t]|\n)*?)
-  (?:\s*\t\s*|\n)
-(\d{4})
-  (?:\s*\t\s*|\n)
-([0-9,]+)\.(\d\d)
-  (?:\s*\t?\s*|\n)
-(CR|DB)
-  (?:\s*\t\s*|\n)
-([0-9,]+)\.(\d\d)
+(\d\d/\d\d|\s?PEND|\s?NEXT) # 1) date
+  (?:\s*\t\s*|\n)+
+((?:[^\t]|\n)*?) # 2) description
+  (?:\s*\t\s*|\n)+
+(\d{4}) # 3) branch code
+  (?:\s*\t\s*|\n)+
+([0-9,]+)\.(\d\d) # 4+5) amount
+  (?:\s*\t?\s*|\n)+
+(CR|DB) # 6)
+  (?:\s*\t\s*|\n)+
+([0-9,]+)\.(\d\d) # 7+8) balance
     !mxg) {
         push @e, {date=>$1, desc=>$2, br=>$3, amt=>$4, amtf=>$5, crdb=>$6, bal=>$7, balf=>$8};
     }
@@ -439,7 +439,7 @@ Finance::Bank::ID::BCA - Check your BCA accounts from Perl
 
 =head1 VERSION
 
-This document describes version 0.46 of Finance::Bank::ID::BCA (from Perl distribution Finance-Bank-ID-BCA), released on 2017-07-01.
+This document describes version 0.47 of Finance::Bank::ID::BCA (from Perl distribution Finance-Bank-ID-BCA), released on 2017-07-20.
 
 =head1 SYNOPSIS
 
